@@ -511,4 +511,11 @@ get_named_expressions = function(dots){
 fix_datatable = function(x){
     if(is.data.table(x)) setDT(x, check.names = FALSE)
     x
+}
+
+######
+
+set_names = function (object = nm, nm){
+    names(object) <- nm
+    object
 }
\ No newline at end of file
