@@ -56,23 +56,23 @@
 #'        matrix(sample(c(1:10,NA), 30, replace = TRUE), 10)
 #' )
 #' 
-#' result  = compute(sheet1, {
+#' result  = let(sheet1, 
 #'              # count 8
-#'              exact = count_row_if(8, V1, V2, V3)
+#'              exact = count_row_if(8, V1, V2, V3),
 #'              # count values greater than 8
-#'              greater = count_row_if(gt(8), V1, V2, V3)
+#'              greater = count_row_if(gt(8), V1, V2, V3),
 #'              # count integer values between 5 and 8, e. g. 5, 6, 7, 8
-#'              integer_range = count_row_if(5:8, V1, V2, V3)
+#'              integer_range = count_row_if(5:8, V1, V2, V3),
 #'              # count values between 5 and 8 
-#'              range = count_row_if(5 %thru% 8, V1, V2, V3)
+#'              range = count_row_if(5 %thru% 8, V1, V2, V3),
 #'              # count NA 
-#'              na = count_row_if(is.na, V1, V2, V3)
+#'              na = count_row_if(is.na, V1, V2, V3),
 #'              # count not-NA 
-#'              not_na = count_row_if(not_na, V1, V2, V3) 
+#'              not_na = count_row_if(not_na, V1, V2, V3), 
 #'              # are there any 5 in each row?
 #'              has_five = cbind(V1, V2, V3) %row_in% 5   
-#'          })  
-#' result
+#'          )  
+#' print(result)
 #'  
 #' mean_row_if(6, sheet1$V1, data = sheet1)
 #' median_row_if(gt(2), sheet1$V1, sheet1$V2, sheet1$V3) 
@@ -99,7 +99,7 @@
 #' 
 #' count_if("apples", sheet1) # 2
 #' 
-#' calc(sheet1, count_if("apples", a, b)) # 2
+#' with(sheet1, count_if("apples", a, b)) # 2
 #' 
 #' count_if(gt(55), sheet1$b) # greater than 55 = 2
 #' 
@@ -135,16 +135,16 @@
 #' )
 #' 
 #' # Sum of commision for property value greater than 160000
-#' calc(sheet1, sum_if(gt(160000), property_value, data = commission)) # 63000
+#' with(sheet1, sum_if(gt(160000), property_value, data = commission)) # 63000
 #'     
 #' # Sum of property value greater than 160000
-#' calc(sheet1, sum_if(gt(160000), property_value)) # 900000
+#' with(sheet1, sum_if(gt(160000), property_value)) # 900000
 #' 
 #' # Sum of commision for property value equals to 300000
-#' calc(sheet1, sum_if(300000, property_value, data = commission)) # 21000
+#' with(sheet1, sum_if(300000, property_value, data = commission)) # 21000
 #'     
 #' # Sum of commision for property value greater than first value of data
-#' calc(sheet1, sum_if(gt(data[1]), property_value, data = commission)) # 49000
+#' with(sheet1, sum_if(gt(data[1]), property_value, data = commission)) # 49000
 #'     
 #' sheet1 = text_to_columns(
 #'        "
@@ -159,16 +159,16 @@
 #'        )
 #' 
 #' # Sum of sales for Fruits
-#' calc(sheet1, sum_if("Fruits", category, data = sales)) # 2000
+#' with(sheet1, sum_if("Fruits", category, data = sales)) # 2000
 #' 
 #' # Sum of sales for Vegetables    
-#' calc(sheet1, sum_if("Vegetables", category, data = sales)) # 12000
+#' with(sheet1, sum_if("Vegetables", category, data = sales)) # 12000
 #' 
 #' # Sum of sales for food which is ending on 'es' 
-#' calc(sheet1, sum_if(perl("es$"), food, data = sales)) # 4300
+#' with(sheet1, sum_if(perl("es$"), food, data = sales)) # 4300
 #' 
 #' # Sum of sales for empty category
-#' calc(sheet1, sum_if(NA, category, data = sales))  # 400
+#' with(sheet1, sum_if(NA, category, data = sales))  # 400
 #' 
 #' 
 #' sheet1 = text_to_columns(
@@ -182,14 +182,14 @@
 #' )
 #' 
 #' # Commision average for comission less than 23000
-#' calc(sheet1, mean_if(lt(23000), commission)) # 14000
+#' with(sheet1, mean_if(lt(23000), commission)) # 14000
 #' 
 #' 
 #' # Property value average for property value less than 95000
-#' calc(sheet1, mean_if(lt(95000), property_value)) #  NaN
+#' with(sheet1, mean_if(lt(95000), property_value)) #  NaN
 #' 
 #' # Commision average for property value greater than 250000
-#' calc(sheet1, mean_if(gt(250000), property_value, data = commission)) # 24500
+#' with(sheet1, mean_if(gt(250000), property_value, data = commission)) # 24500
 #' 
 #' 
 #' sheet1 = text_to_columns(
@@ -206,11 +206,11 @@
 #' 
 #' 
 #' # Mean profits for 'west' regions
-#' calc(sheet1, mean_if(contains("West"), region, data = profits)) # 16733.5
+#' with(sheet1, mean_if(contains("West"), region, data = profits)) # 16733.5
 #' 
 #' 
 #' # Mean profits for regions wich doesn't contain New Office
-#' calc(sheet1, mean_if(not(contains("New Office")), region, data = profits))  # 18589
+#' with(sheet1, mean_if(not(contains("New Office")), region, data = profits))  # 18589
 #' 
 #' 
 #' sheet1 = text_to_columns(
@@ -226,11 +226,11 @@
 #' )
 #' 
 #' # Minimum grade for weight equals to 1
-#' calc(sheet1, min_if(1, weight, data = grade)) # 88
+#' with(sheet1, min_if(1, weight, data = grade)) # 88
 #' 
 #' 
 #' # Maximum grade for weight equals to 1
-#' calc(sheet1, max_if(1, weight, data = grade)) #91
+#' with(sheet1, max_if(1, weight, data = grade)) #91
 #' 
 #' 
 #' # Example with offset
@@ -246,7 +246,7 @@
 #'     "
 #' )
 #' 
-#' calc(sheet1, min_if("a", grade[2:5], data = weight[1:4])) # 10
+#' with(sheet1, min_if("a", grade[2:5], data = weight[1:4])) # 10
 #' 
 #' 
 count_if=function(criterion,...){
@@ -272,18 +272,19 @@ count_col_if=function(criterion,...){
 }
 
 
-
-
 #' @export
 #' @rdname count_if
-'%row_in%'=function(x, criterion){
+has = function(x, criterion){
     cond = build_condition_matrix(criterion, x)
     matrixStats::rowAnys(cond)
 }
 
 #' @export
 #' @rdname count_if
-'%has%' = `%row_in%`
+'%row_in%'= has
+#' @export
+#' @rdname count_if
+'%has%' = has
 
 #' @export
 #' @rdname count_if
