@@ -6,57 +6,41 @@ if(isTRUE(getOption("covr"))){
     
     
     data(mtcars)
-    mtcars = modify(mtcars,{
-        var_lab(mpg) = "Miles/(US) gallon"
-        var_lab(cyl) = "Number of cylinders"
-        var_lab(disp) = "Displacement (cu.in.)"
-        var_lab(hp) = "Gross horsepower"
-        var_lab(drat) = "Rear axle ratio"
-        var_lab(wt) = "Weight (lb/1000)"
-        var_lab(qsec) = "1/4 mile time"
-        var_lab(vs) = "V/S"
-        val_lab(vs) = c("Straight" = 0, "V" = 1)
-        var_lab(am) = "Transmission (0 = automatic, 1 = manual)"
-        val_lab(am) = c(" automatic" = 0, " manual" =  1)
-        var_lab(gear) = "Number of forward gears"
-        var_lab(carb) = "Number of carburetors"
-    })
+    mtcars = apply_labels(mtcars,
+                          mpg = "Miles/(US) gallon",
+                          cyl = "Number of cylinders",
+                          disp = "Displacement (cu.in.)",
+                          hp = "Gross horsepower",
+                          drat = "Rear axle ratio",
+                          wt = "Weight (lb/1000)",
+                          qsec = "1/4 mile time",
+                          vs = "V/S",
+                          vs = c("Straight" = 0, "V" = 1),
+                          am = "Transmission (0 = automatic, 1 = manual)",
+                          am = c(" automatic" = 0, " manual" =  1),
+                          gear = "Number of forward gears",
+                          carb = "Number of carburetors"
+    )
+    
     
     # row_labels = c("row_vars", "row_vars_values", "summary_vars", "fun_names", "stat_names"),
     # col_labels = c("col_vars", "col_vars_values")
     
-    # table_summary(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, fun = mean)
-    # table_means(mtcars %>% except("cyl", "am"), col_vars = mtcars$am)
-    # table_medians(mtcars %>% except("cyl", "am"), col_vars = mtcars$am)
-    # table_sums(mtcars %>% except("cyl", "am"), col_vars = mtcars$am)
-    # table_sums(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, weight = 2)
-    # expect_error(cro_fun(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, 
-    #                      fun = mean)
-    #              )
-    # expect_error(cro_fun(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, fun = mean))
-    # expect_error(cro_fun(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, fun = mean,
-    #               row_labels = c("stat_names", "col_vars_values", "row_vars", "row_vars_values", "summary_vars",  "col_vars"),
-    #               col_labels = c("adasd", "rvtrvtt")
-    # ))
-    # expect_error(cro_fun(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, fun = mean,
-    #               col_labels = c("stat_names", "col_vars_values", "row_vars", "row_vars_values", "summary_vars",  "col_vars"),
-    #               row_labels = c("adasd", "rvtrvtt")
-    # ))
     
     #######
     expect_error(
-        cro_fun(mtcars %>% except("cyl", "am"), col_vars = mtcars$am, fun = mean, weight = 2)
+        cro_fun(mtcars %>% columns(-"cyl", -"am"), col_vars = mtcars$am, fun = mean, weight = 2)
     )
     
     
     
     expect_equal_to_reference(
-        cro_fun(mtcars %>% except("cyl", "am"),
+        cro_fun(mtcars %>% columns(-"cyl", -"am"),
                 col_vars = mtcars$am, fun = combine_functions(w_mean), weight = 2),
         "rds/table_summary0.rds",  update = FALSE)
     
     expect_equal_to_reference(
-        calc_cro_fun(mtcars, ..[!perl("cyl|am")], col_vars = am, 
+        cross_fun(mtcars, ..[!perl("cyl|am")], col_vars = am, 
                      fun = combine_functions(w_mean), 
                      weight = 2
         ),
@@ -65,7 +49,7 @@ if(isTRUE(getOption("covr"))){
     
     
     expect_equal_to_reference(
-        cro_fun(mtcars %>% except("cyl", "am"), col_vars = list("Total", mtcars$am), 
+        cro_fun(mtcars %>% columns(-"cyl", -"am"), col_vars = list("Total", mtcars$am), 
                 fun = combine_functions(mean)),
         "rds/table_summary1.rds",  update = FALSE
     )
@@ -73,43 +57,45 @@ if(isTRUE(getOption("covr"))){
     
     add_val_lab(mtcars$am) = c(HardToSay = 3)
     expect_equal_to_reference(
-        cro_fun(mtcars %>% except("cyl", "am"), col_vars = list("Total", mtcars$am), 
+        cro_fun(mtcars %>% columns(-"cyl", -"am"), col_vars = list("Total", mtcars$am), 
                 fun = combine_functions(mean))
         ,"rds/table_summary2.rds",  update = FALSE
     )
     
     data(mtcars)
-    mtcars = modify(mtcars,{
-        var_lab(mpg) = "Miles/(US) gallon"
-        var_lab(cyl) = "Number of cylinders"
-        var_lab(disp) = "Displacement (cu.in.)"
-        var_lab(hp) = "Gross horsepower"
-        var_lab(drat) = "Rear axle ratio"
-        var_lab(wt) = "Weight (lb/1000)"
-        var_lab(qsec) = "1/4 mile time"
-        var_lab(vs) = "V/S"
-        val_lab(vs) = c("Straight" = 0, "V" = 1)
-        var_lab(am) = "Transmission (0 = automatic, 1 = manual)"
-        val_lab(am) = c(" automatic" = 0, " manual" =  1)
-        var_lab(gear) = "Number of forward gears"
-        var_lab(carb) = "Number of carburetors"
-    })
+    mtcars = apply_labels(mtcars,
+                          mpg = "Miles/(US) gallon",
+                          cyl = "Number of cylinders",
+                          disp = "Displacement (cu.in.)",
+                          hp = "Gross horsepower",
+                          drat = "Rear axle ratio",
+                          wt = "Weight (lb/1000)",
+                          qsec = "1/4 mile time",
+                          vs = "Engine",
+                          vs = c("V-engine" = 0,
+                                 "Straight engine" = 1),
+                          am = "Transmission",
+                          am = c("Automatic" = 0,
+                                 "Manual"=1),
+                          gear = "Number of forward gears",
+                          carb = "Number of carburetors"
+    )
     
     add_val_lab(mtcars$am) = c(HardToSay = 3)
     expect_equal_to_reference(
-        cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+        cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
                 fun = combine_functions(mean))
         ,"rds/table_summary3.rds",  update = FALSE
     )
     
     expect_equal_to_reference(
-        cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+        cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
                 fun = mean)
         ,"rds/table_summary4.rds",  update = FALSE
     )
     
     expect_equal_to_reference(
-        cro_fun_df(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+        cro_fun_df(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
                    fun = function(x) {
                        res = t(colMeans(x) )
                        rownames(res) = "mean"
@@ -119,7 +105,7 @@ if(isTRUE(getOption("covr"))){
     )
     
     expect_equal_to_reference(
-        calc_cro_fun_df(mtcars, ..[!perl("vs|am")], 
+        cross_fun_df(mtcars, ..[!perl("vs|am")], 
                         col_vars = list("Total", mtcars$am),
                         fun = function(x) {
                             res = t(colMeans(x) )
@@ -130,7 +116,7 @@ if(isTRUE(getOption("covr"))){
     )
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_labels = c("row_vars", "row_vars_values", "stat_names"),
     #               col_labels = c("col_vars", "summary_vars", "col_vars_values"), fun = mean)
     # ,"rds/table_summary6.rds",  update = FALSE
@@ -140,7 +126,7 @@ if(isTRUE(getOption("covr"))){
     ########## rowlabels
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #              fun = combine_functions(mean))
     # ,"rds/table_summary7.rds",  update = FALSE
@@ -148,7 +134,7 @@ if(isTRUE(getOption("covr"))){
     
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #               row_labels = c("row_vars", "row_vars_values", "summary_vars"),
     #               col_labels = c("col_vars", "col_vars_values", "stat_names"), fun = mean)
@@ -156,7 +142,7 @@ if(isTRUE(getOption("covr"))){
     # )
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), 
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), 
     #               col_vars = mtcars$vs,
     #         row_vars = list("Total", mtcars$am), 
     #         fun = mean)
@@ -164,7 +150,7 @@ if(isTRUE(getOption("covr"))){
     # )
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #               row_labels = c("row_vars", "row_vars_values",  "col_vars_values", "summary_vars", "stat_names"),
     #               col_labels = c("col_vars"), fun = mean)
@@ -174,13 +160,13 @@ if(isTRUE(getOption("covr"))){
     add_val_lab(mtcars$vs) = c("Don't know" = 88)
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs, fun = combine_functions(mean))
     # ,"rds/table_summary11.rds",  update = FALSE
     # )
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #               row_labels = c("row_vars", "row_vars_values", "summary_vars"),
     #               col_labels = c("col_vars", "col_vars_values", "stat_names"), fun = mean)
@@ -189,7 +175,7 @@ if(isTRUE(getOption("covr"))){
     
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #               row_labels = c("row_vars", "row_vars_values", "summary_vars", "stat_names"),
     #               col_labels = c("col_vars", "col_vars_values", "summary_vars"), fun = mean)
@@ -198,7 +184,7 @@ if(isTRUE(getOption("covr"))){
     
     
     expect_equal_to_reference(
-        cro_fun_df(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+        cro_fun_df(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
                    row_vars = mtcars$vs, 
                    fun = function(x) {
                        res = t(colMeans(x) )
@@ -210,7 +196,7 @@ if(isTRUE(getOption("covr"))){
     
     
     # expect_equal_to_reference(
-    # cro_fun(mtcars %>% except("vs", "am"), col_vars = list("Total", mtcars$am),
+    # cro_fun(mtcars %>% columns(-"vs", -"am"), col_vars = list("Total", mtcars$am),
     #               row_vars = mtcars$vs,
     #               row_labels = c("row_vars", "row_vars_values",  "col_vars_values", "summary_vars", "stat_names"),
     #               col_labels = c("col_vars"), fun = mean)
@@ -233,30 +219,31 @@ if(isTRUE(getOption("covr"))){
                           99 Hard to answer
                           ")
     
-    w = compute(w, {
+    w = w %>% let( 
         # recode age by groups
         age_cat = if_val(s2a, lo %thru% 25 ~ 1, lo %thru% hi ~ 2)
         
+    ) %>% 
         # Apply labels
-        
-        var_lab(c1) = "Preferences"
-        val_lab(c1) = num_lab("
+        apply_labels(
+            c1 = "Preferences",
+            c1 = num_lab("
                           1 VSX123 
                           2 SDF456
                           3 Hard to say
-                          ")
-        
-        var_lab(age_cat) = "Age"
-        val_lab(age_cat) = c("18 - 25" = 1, "26 - 35" = 2)
-        
-        var_lab(a1_1) = "Likes. VSX123"
-        var_lab(b1_1) = "Likes. SDF456"
-        val_lab(a1_1) = codeframe_likes
-        val_lab(b1_1) = codeframe_likes
-        
-        var_lab(a22) = "Overall quality. VSX123"
-        var_lab(b22) = "Overall quality. SDF456"
-        val_lab(a22) = num_lab("
+                          "),
+            
+            age_cat = "Age",
+            age_cat = c("18 - 25" = 1, "26 - 35" = 2),
+            
+            a1_1 = "Likes. VSX123",
+            b1_1 = "Likes. SDF456",
+            a1_1 = codeframe_likes,
+            b1_1 = codeframe_likes,
+            
+            a22 = "Overall quality. VSX123",
+            b22 = "Overall quality. SDF456",
+            a22 = num_lab("
                            1 Extremely poor 
                            2 Very poor
                            3 Quite poor
@@ -264,9 +251,9 @@ if(isTRUE(getOption("covr"))){
                            5 Quite good
                            6 Very good
                            7 Excellent
-                           ")
-        val_lab(b22) = val_lab(a22)
-    })
+                           "),
+            b22 = val_lab(a22)
+        )
     
     expect_equal_to_reference(
         calc(w, cro_fun(list(a22, b22), col_vars = mrset(a1_1 %to% a1_6), fun = combine_functions(w_mean)))
@@ -330,53 +317,48 @@ if(isTRUE(getOption("covr"))){
     context("cro_mean_sd_n")
     
     data(mtcars)
-    mtcars = modify(mtcars,{
-        var_lab(mpg) = "Miles/(US) gallon"
-        var_lab(cyl) = "Number of cylinders"
-        var_lab(disp) = "Displacement (cu.in.)"
-        var_lab(hp) = "Gross horsepower"
-        var_lab(drat) = "Rear axle ratio"
-        var_lab(wt) = "Weight (lb/1000)"
-        var_lab(qsec) = "1/4 mile time"
-        var_lab(vs) = "V/S"
-        val_lab(vs) = c("Straight" = 0, "V" = 1)
-        var_lab(am) = "Transmission (0 = automatic, 1 = manual)"
-        val_lab(am) = c(" automatic" = 0, " manual" =  1)
-        var_lab(gear) = "Number of forward gears"
-        var_lab(carb) = "Number of carburetors"
-    })
+    mtcars = apply_labels(mtcars,
+                          mpg = "Miles/(US) gallon",
+                          cyl = "Number of cylinders",
+                          disp = "Displacement (cu.in.)",
+                          hp = "Gross horsepower",
+                          drat = "Rear axle ratio",
+                          wt = "Weight (lb/1000)",
+                          qsec = "1/4 mile time",
+                          vs = "Engine",
+                          vs = c("V-engine" = 0,
+                                 "Straight engine" = 1),
+                          am = "Transmission",
+                          am = c("Automatic" = 0,
+                                 "Manual"=1),
+                          gear = "Number of forward gears",
+                          carb = "Number of carburetors"
+    )
     
     expect_equal_to_reference(
-        mtcars %calc% cro_mean_sd_n(list(mpg, disp, wt), list(total(), am, vs)),
+        with(mtcars, cro_mean_sd_n(list(mpg, disp, wt), list(total(), am, vs))),
         "rds/cro_mean_sd_n1.rds",  update = FALSE
     )
     
     
     expect_equal_to_reference(
-        calc_cro_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs)),
+        cross_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs)),
         "rds/cro_mean_sd_n1.rds",  update = FALSE
     )
     
-    expect_error(calc_cro_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs), labels = 1))
-    expect_error(calc_cro_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs), 
+    expect_error(cross_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs), labels = 1))
+    expect_error(cross_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs), 
                                     labels = c("", "", "")))
     
     expect_equal_to_reference(
-        mtcars %calc% cro_mean_sd_n(list(mpg, disp, wt), list(total(), am, vs), weight = 0.1,
+         cross_mean_sd_n(mtcars, list(mpg, disp, wt), list(total(), am, vs), weight = 0.1,
                                     weighted_valid_n = TRUE),
         "rds/cro_mean_sd_n2.rds",  update = FALSE
     )
     
-    expect_equal_to_reference(
-        mtcars %calc% cro_mean_sd_n(list(mpg, disp, wt), list(total(), am, vs), 
-                                    labels = c("m", "s", "n"),
-                                    weight = 0.1,
-                                    weighted_valid_n = TRUE),
-        "rds/cro_mean_sd_n3.rds",  update = FALSE
-    )
     
     expect_equal_to_reference(
-        calc_cro_mean_sd_n(mtcars, 
+        cross_mean_sd_n(mtcars, 
                            list(mpg, disp, wt), 
                            list(total(), am, vs), 
                            labels = c("m", "s", "n"),
@@ -393,7 +375,7 @@ if(isTRUE(getOption("covr"))){
     mtcars2$ww = runif(NROW(mtcars), 0.5, 1.5)
     mtcars2$ww[6:10] = NA
     mtcars2$empty = NA
-    expect_equal_to_reference(calc_cro_mean_sd_n(mtcars2, 
+    expect_equal_to_reference(cross_mean_sd_n(mtcars2, 
                                                  empty, 
                                                  list(total(), am, vs),
                                                  weight = ww,
@@ -402,7 +384,7 @@ if(isTRUE(getOption("covr"))){
     )
     
     expect_equal_to_reference(
-        calc_cro_mean_sd_n(mtcars2, 
+        cross_mean_sd_n(mtcars2, 
                            empty, 
                            list(total(), am, vs),
                            weight = ww,
@@ -420,7 +402,7 @@ if(isTRUE(getOption("covr"))){
         "rds/cro_mean_sd_n4_1.rds",  update = FALSE
     )
     mtcars2$empty = NA_real_
-    expect_equal_to_reference(calc_cro_mean_sd_n(mtcars2, 
+    expect_equal_to_reference(cross_mean_sd_n(mtcars2, 
                                                  empty, 
                                                  list(total(), am, vs),
                                                  weight = ww,
@@ -428,7 +410,7 @@ if(isTRUE(getOption("covr"))){
                               "rds/cro_mean_sd_n4.rds",  update = FALSE
     )
     
-    expect_equal_to_reference(calc_cro_mean_sd_n(mtcars2, 
+    expect_equal_to_reference(cross_mean_sd_n(mtcars2, 
                                                  empty, 
                                                  list(total(), am, vs),
                                                  weight = ww,
