@@ -2,11 +2,11 @@ context("merge etable")
 
 data("mtcars")
 
-mtcars = modify(mtcars, {
-    var_lab(vs) = "vs"
-    var_lab(am) = "am"
-    var_lab(gear) = "gear"
-    var_lab(carb) = "carb"})
+
+var_lab(mtcars$vs) = "vs"
+var_lab(mtcars$am) = "am"
+var_lab(mtcars$gear) = "gear"
+var_lab(mtcars$carb) = "carb"
 
 expect_equal_to_reference(with(mtcars, {
     counts = cro(list(vs, am, gear, carb), list("Count"), total_row_position = "none")
@@ -67,71 +67,24 @@ expect_equal_to_reference(with(mtcars, {
     merge(counts, counts)
 }), "rds/merge6.rds",  update = FALSE)
 
-context("%merge%")
-
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(vs, am, gear, carb), list("Count"), total_row_position = "none")
-    percents = cro_cpct(list(vs, am, gear, carb), list("Column N %"), total_row_position = "none")
-    counts %merge% percents
-}), "rds/merge1.rds",  update = FALSE)
-
-### weird
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(vs, am, gear, am), list("Count"), total_row_position = "none")
-    percents = cro_cpct(list(vs, am, vs, carb), list("Column N %"), total_row_position = "none")
-    counts %merge% percents
-}), "rds/merge2.rds",  update = FALSE)
-
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(vs, am), list("Count"), total_row_position = "none")
-    percents = cro_cpct(list(gear, carb), list("Column N %"), total_row_position = "none")
-    counts %merge% percents
-}), "rds/merge3.rds",  update = FALSE)
-
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(am, gear, carb), list("Count"), total_row_position = "none")
-    percents = cro_cpct(list(vs, am, gear, carb), list("Column N %"), total_row_position = "none")
-    counts %merge% percents
-}), "rds/merge4.rds",  update = FALSE)
-
-####
-expect_equal_to_reference(
-    with(mtcars, {
-        counts = cro(list(vs, am, gear, carb), list("Count"), total_row_position = "above")
-        percents = cro_cpct(list(vs, gear, carb), list("Column N %"), total_row_position = "above")
-        counts %merge% percents
-
-    }), "rds/merge4a.rds",  update = FALSE)
-
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(vs, gear, carb), list("Count"), total_row_position = "none")
-    percents = cro_cpct(list(vs, am, gear, carb), list("Column N %"), total_row_position = "none")
-    counts %merge% percents
-}), "rds/merge5.rds",  update = FALSE)
-
-expect_equal_to_reference(with(mtcars, {
-    counts = cro(list(vs, gear, carb), list("Count"))
-    counts %merge% counts
-}), "rds/merge6.rds",  update = FALSE)
-
 
 context("merge etable")
 
 data("mtcars")
 
-mtcars = modify(mtcars, {
-    var_lab(vs) = "vs"
-    var_lab(am) = "am"
-    val_lab(am) = c("automatic transmission" = 1, "manual transmission" = 0)
-    var_lab(gear) = "gear"
-    var_lab(carb) = "carb"})
+
+var_lab(mtcars$vs) = "vs"
+var_lab(mtcars$am) = "am"
+val_lab(mtcars$am) = c("automatic transmission" = 1, "manual transmission" = 0)
+var_lab(mtcars$gear) = "gear"
+var_lab(mtcars$carb) = "carb"
 
 
 expect_equal_to_reference(with(mtcars,{
     freq = fre(carb)
     cross = cro(list(unvr(carb)), list(unvr(am), total()),
                 total_label = "#Total") 
-    freq %merge% cross
+    merge(freq, cross)
 
 
 }), "rds/merge7.rds",  update = FALSE)
@@ -139,7 +92,7 @@ expect_equal_to_reference(with(mtcars,{
 expect_equal_to_reference(with(mtcars,{
     freq = fre(carb)
     cross = cro(list(unvr(carb)), list(unvr(am), total()), total_label = "#Total")
-    cross %merge% freq
+    cross  %>%  merge(freq)
 
 
 }), "rds/merge8.rds",  update = FALSE)
@@ -147,7 +100,7 @@ expect_equal_to_reference(with(mtcars,{
 expect_equal_to_reference(with(mtcars,{
     freq = fre(carb[carb!=2])
     cross = cro(list(unvr(carb[carb!=4])), list(unvr(am[carb!=4]), "#Total"), total_label = "#Total")
-    freq %merge% cross
+    freq %>% add_columns(cross)
 
 
 }), "rds/merge9.rds",  update = FALSE)
@@ -156,7 +109,7 @@ expect_equal_to_reference(with(mtcars,{
 expect_equal_to_reference(with(mtcars,{
     freq = fre(carb)
     cross = cro(list(unvr(vs)), list(unvr(am), total()), total_label = "#Total")
-    cross %merge% freq
+    add_columns(cross, freq)
 
 
 }), "rds/merge10.rds",  update = FALSE)
@@ -171,12 +124,12 @@ expect_equal_to_reference(with(mtcars,{
 context("merge simple_summary")
 data("mtcars")
 
-mtcars = modify(mtcars, {
-    var_lab(vs) = "vs"
-    var_lab(am) = "am"
-    val_lab(am) = c("automatic transmission" = 1, "manual transmission" = 0)
-    var_lab(gear) = "gear"
-    var_lab(carb) = "carb"})
+
+var_lab(mtcars$vs) = "vs"
+var_lab(mtcars$am) = "am"
+val_lab(mtcars$am) = c("automatic transmission" = 1, "manual transmission" = 0)
+var_lab(mtcars$gear) = "gear"
+var_lab(mtcars$carb) = "carb"
 
 expect_equal_to_reference(
     with(mtcars, 
@@ -198,8 +151,8 @@ expect_equal_to_reference(
 
 expect_equal_to_reference(
     with(mtcars, 
-         cro_mean(list(V1 = mpg, gear, carb), list(unvr(am), total()))  %merge%  
-             cro_mean(list(gear, carb), list(unvr(am), total()))
+         merge(cro_mean(list(V1 = mpg, gear, carb), list(unvr(am), total())),  
+             cro_mean(list(gear, carb), list(unvr(am), total())))
          
     ), 
     "rds/merge_simple_summary1.rds",  update = FALSE)
@@ -207,26 +160,19 @@ expect_equal_to_reference(
 
 expect_equal_to_reference(
     with(mtcars, 
-         cro_mean(list(V1 = mpg, gear, carb), list(unvr(am), total())) %merge%
-               cro_mean(list(gear, carb), list(unvr(vs), total()))
+         merge(cro_mean(list(V1 = mpg, gear, carb), list(unvr(am), total())),
+               cro_mean(list(gear, carb), list(unvr(vs), total())))
          
     ), 
     "rds/merge_simple_summary2.rds",  update = FALSE)
 
 
-context("left join")
-
-a = sheet(x = 1:5, y = 11:15)
-b = sheet(x = 3:7, z = 13:17)
-d = sheet(t = 3:7, z = 13:17)
-expect_identical(a %merge% b, merge(a, b, all.x = TRUE, all.y = FALSE))
-expect_error(a %merge% d)
 
 
 context("merge duplicated columns")
 
 data(mtcars)
-expect_equal_to_reference(fre(mtcars$cyl[mtcars$mpg<20]) %merge% fre(mtcars$cyl) ,
+expect_equal_to_reference(merge(fre(mtcars$cyl[mtcars$mpg<20]), fre(mtcars$cyl)) ,
                            "rds/merge12.rds",  update = FALSE)
 
 context("merge duplicated rows")
@@ -245,13 +191,13 @@ tabl2 = mtcars %>%
     tab_pivot()
 
 expect_equal_to_reference(
-    tabl1 %merge% tabl2,
+   merge(tabl1, tabl2),
     "rds/merge13.rds",  update = FALSE)
 expect_equal_to_reference(
-    tabl2 %merge% tabl1,
+    merge(tabl2, tabl1),
     "rds/merge14.rds",  update = FALSE)
 expect_equal_to_reference(
-    tabl1 %merge% tabl1,
+    merge(tabl1, tabl1),
     "rds/merge15.rds",  update = FALSE)
 
 
